---
hide:
  - navigation
---

# Paradex Python SDK

!!! warning
    **Experimental SDK, library API is subject to change**

::: paradex_py.paradex.Paradex
    handler: python
    options:
      show_source: false
      show_root_heading: true

## API Documentation Links

Full details for REST API & WebSocket JSON-RPC API can be found at the following links:

- [Environment - Testnet](https://docs.api.testnet.paradex.trade){:target="_blank"}
- [Environment - Prod](https://docs.api.prod.paradex.trade){:target="_blank"}

::: paradex_py.api.api_client.ParadexApiClient
    handler: python
    options:
      show_source: false
      show_root_heading: true

::: paradex_py.api.ws_client.ParadexWebsocketChannel
    handler: python
    options:
      show_source: false
      show_root_heading: true

::: paradex_py.api.ws_client.ParadexWebsocketClient
    handler: python
    options:
      show_source: false
      show_root_heading: true

::: paradex_py.account.account.ParadexAccount
    handler: python
    options:
      show_source: false
      show_root_heading: true
